% FUNCTION Y = LOGKSUM(LOGK_X, K)
%
% logk_x : vector containing logk(xi)
% k :     scalar, log order (not necessarily an integer)
% y     : scalar, estimation of logk(sum over i of xi)

function y = logksum(logk_x, k)

y = logsum(logk_x * log(k)) / log(k);
